import React, { useEffect, useMemo, useState } from 'react'
import { Select, message } from 'antd'
import { getUserSelector } from '../../../../../apis/process'

const UserSelect = (props) => {

  const userID = window?.globalConfig?.userInfo?.OID || 1
  const { value, onChange, schema, addons } = props
  const { disabled, presetValue, isMultiple, placeholder, role, isStoreID, isMySite } = schema
  const property = isStoreID ? 'userID' : 'userName'
  const [pullDown, setPullDown] = useState([])
  const [searchValue, setSearchValue] = useState('')

  const options = useMemo(() => {
    let array = []
    pullDown.forEach(v => {
      if (searchValue) {
        if (v?.label?.includes(searchValue)) {
          array.push(v)
        }
      } else {
        array.push(v)
      }
    })
    if (array.length > 200) {
      return array.slice(0, 199)
    }
    return array
  }, [pullDown, searchValue])

  const valueShow = useMemo(() => {
    if (isMultiple) {
      return value ? value.split(',') : []
    }
    return value || null
  }, [value, isMultiple])

  const onSearch = (value) => {
    setSearchValue(value)
  }

  const selectFocus = async () => {
    let time = new Date().getTime() + Math.random()
    const { code, data, msg } = await getUserSelector(role, isMySite ? userID : false, time)
    if (code === 0) {
      if (data) {
        setPullDown(data.dropdownList.map(v => { return { label: v.userName, value: v[property], groupName: v.groupName } }))
      } else {
        setPullDown([])
      }
    } else {
      message.info(msg)
    }
  }

  const selectChange = (value) => {
    if (addons) {
      onChange(isMultiple ? value.join(',') : value)
    }
  }

  useEffect(() => {
    if (addons) {
      addons.setValue(addons.dataPath, presetValue)
    } else {
      onChange(presetValue)
    }
  }, [presetValue])

  useEffect(() => {
    if (isStoreID) {
      selectFocus()
    }
  }, [])

  console.log('options', options)

  return (
    <Select
      mode={isMultiple ? 'multiple' : null}
      placeholder={disabled ? (placeholder || '') : (placeholder || '点击选择人员')}
      value={valueShow}
      disabled={disabled}
      showArrow={!disabled}
      showSearch={true}
      onSearch={onSearch}
      searchValue={searchValue}
      style={{ width: '100%' }}
      onFocus={selectFocus}
      onChange={selectChange}
    >
      {
        options.map((v, i) => {
          let length = v.groupName?.length
          return (
            <Select.Option key={v.value + i} value={v.value}>
              <div style={{ display: 'flex', justifyContent: 'space-between' }}>
                <span>{v.label}</span>
                <span style={{ fontSize: '12px', color: '#b4b1b1', }}>{v.groupName?.length > 20 ? `...${v.groupName.slice(v.groupName.length - 20, length)}` : v.groupName}</span>
              </div>
            </Select.Option>
          )
        })
      }
    </Select>
  )

}

export default UserSelect